@@ -35,7 +35,7 @@ from vantage6.common.globals import (
     DEFAULT_NODE_IMAGE
 )
 from vantage6.common.globals import VPN_CONFIG_FILE
-from vantage6.common.docker_addons import (
+from vantage6.common.docker.addons import (
   pull_if_newer,
   remove_container_if_exists,
   check_docker_running
@@ -289,10 +289,19 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
     # Then we check if the image has been specified in the config file, and
     # finally we use the default settings from the package.
     if not image:
-        image = ctx.config.get(
-            "image",
-            f"{DEFAULT_DOCKER_REGISTRY}/{DEFAULT_NODE_IMAGE}"
-        )
+
+        # FIXME: remove me in version 4+, as this is to support older
+        # configuration files. So the outer `image` key is no longer supported
+        if ctx.config.get('image'):
+            warning('Using the `image` option in the config file is to be '
+                    'removed in version 4+.')
+            image = ctx.config.get('image')
+
+        custom_images: dict = ctx.config.get('images')
+        if custom_images:
+            image = custom_images.get("node")
+        if not image:
+            image = f"{DEFAULT_DOCKER_REGISTRY}/{DEFAULT_NODE_IMAGE}"
 
     info(f"Pulling latest node image '{image}'")
     try:
@@ -419,6 +428,8 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
                 time.sleep(1)
             except KeyboardInterrupt:
                 info("Closing log file. Keyboard Interrupt.")
+                info("Note that your node is still running! Shut it down with "
+                     f"'{Fore.RED}vnode stop{Style.RESET_ALL}'")
                 exit(0)
 
 
@@ -430,7 +441,8 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
 @click.option('--system', 'system_folders', flag_value=True)
 @click.option('--user', 'system_folders', flag_value=False, default=N_FOL)
 @click.option('--all', 'all_nodes', flag_value=True)
-def cli_node_stop(name, system_folders, all_nodes):
+@click.option('--force', 'force', flag_value=True, help="kills containers instantly")
+def cli_node_stop(name, system_folders, all_nodes, force):
     """Stop a running container. """
 
     client = docker.from_env()
@@ -442,10 +454,19 @@ def cli_node_stop(name, system_folders, all_nodes):
         warning("No nodes are currently running.")
         return
 
+    if force:
+        warning('Forcing the node to stop will not terminate helper '
+                'containers, neither will it remove routing rules made on the '
+                'host!')
+
+
     if all_nodes:
         for name in running_node_names:
             container = client.containers.get(name)
-            container.kill()
+            if force:
+                container.kill()
+            else:
+                container.stop()
             info(f"Stopped the {Fore.GREEN}{name}{Style.RESET_ALL} Node.")
     else:
         if not name:
@@ -460,7 +481,10 @@ def cli_node_stop(name, system_folders, all_nodes):
             container = client.containers.get(name)
             # Stop the container. Using stop() gives the container 10s to exit
             # itself, if not then it will be killed
-            container.stop()
+            if force:
+                container.kill()
+            else:
+                container.stop()
             info(f"Stopped the {Fore.GREEN}{name}{Style.RESET_ALL} Node.")
         else:
             error(f"{Fore.RED}{name}{Style.RESET_ALL} is not running?")
@@ -497,6 +521,8 @@ def cli_node_attach(name, system_folders):
                 time.sleep(1)
             except KeyboardInterrupt:
                 info("Closing log file. Keyboard Interrupt.")
+                info("Note that your node is still running! Shut it down with "
+                     f"'{Fore.RED}vnode stop{Style.RESET_ALL}'")
                 exit(0)
     else:
         error(f"{Fore.RED}{name}{Style.RESET_ALL} was not running!?")
@@ -547,6 +573,9 @@ def cli_node_create_private_key(name, config, environment, system_folders,
         client = create_client_and_authenticate(ctx)
         organization_name = client.whoami.organization_name
 
+    # create directory where private key goes if it doesn't exist yet
+    ctx.type_data_folder(system_folders).mkdir(parents=True, exist_ok=True)
+
     # generate new key, and save it
     filename = f"privkey_{organization_name}.pem"
     file_ = ctx.type_data_folder(system_folders) / filename
@@ -699,7 +728,7 @@ def cli_node_remove(name, environment, system_folders):
                       system_folders=system_folders)
 
     # remove the docker volume and any temporary volumes
-    debug(f"Deleting docker volumes")
+    debug("Deleting docker volumes")
     volumes = client.volumes.list()
     for vol in volumes:
         if vol.name.startswith(ctx.docker_volume_name):  # includes tmp volumes
@@ -711,7 +740,7 @@ def cli_node_remove(name, environment, system_folders):
             vol.remove()
 
     # remove the VPN configuration file
-    vpn_config_file = os.path.join(ctx.data_dir, VPN_CONFIG_FILE)
+    vpn_config_file = os.path.join(ctx.data_dir, 'vpn', VPN_CONFIG_FILE)
     remove_file(vpn_config_file, 'VPN configuration')
 
     # remove the config file
